pub enum GitOp {
ClientFetchServerPush,
ClientPushServerFetch,
}Expand description
Git operation client request.
Variants
ClientFetchServerPush
Client is doing a fetch. Server runs git-upload-pack.
ClientPushServerFetch
Client is going a push. Server runs git-fetch-pack.
Implementations
Sourceimpl GitOp
impl GitOp
Sourcepub fn resource_id<S: Display>(self, resource: S) -> Vec<u8> ⓘ
pub fn resource_id<S: Display>(self, resource: S) -> Vec<u8> ⓘ
Return the resource ID that will be authorized for the operation on the git repository path. The operation must currently be bound to the authorized resource_id, otherwise the transfer function has no way to know what was authorized.
pub async fn write_request<W: AsyncWrite + Unpin, S: Display>( self, w: &mut W, resource: S, ) -> Result<(), Error>
pub fn from_resource_id(resource_id: &[u8]) -> Result<GitOp, Error>
pub fn to_byte(self) -> u8
pub fn from_byte(b: u8) -> Option<Self>